@@ -1985,15 +1985,6 @@ gnc_ui_new_accounts_from_name_window (GtkWindow *parent, const char *name)
                                                          NULL, NULL);
 }
 
-Account *
-gnc_ui_new_accounts_from_name_window_with_types (GtkWindow *parent,
-                                                 const char *name,
-                                                 GList *valid_types)
-{
-    return gnc_ui_new_accounts_from_name_with_defaults (parent, name,
-                                                        valid_types, NULL, NULL);
-}
-
 Account *
 gnc_ui_new_accounts_from_name_with_defaults (GtkWindow *parent,
                                              const char *name,
@@ -2143,6 +2134,14 @@ gnc_ui_edit_account_window (GtkWindow *parent, Account *account)
     gtk_window_present (GTK_WINDOW(aw->dialog));
 }
 
+void
+gnc_ui_new_account_with_types_and_commodity (GtkWindow *parent, QofBook *book, GList *valid_types,
+                                             gnc_commodity *default_commodity)
+{
+    gnc_ui_new_account_window_internal (parent, book, NULL, NULL,
+                                        valid_types, default_commodity, FALSE);
+}
+
 /*
  * opens up a window to create a new account
  *
@@ -2161,14 +2160,6 @@ gnc_ui_new_account_window (GtkWindow *parent, QofBook *book,
                                         NULL, FALSE);
 }
 
-void
-gnc_ui_new_account_with_types (GtkWindow *parent, QofBook *book,
-                               GList *valid_types)
-{
-    gnc_ui_new_account_window_internal (parent, book, NULL, NULL,
-                                        valid_types, NULL, FALSE);
-}
-
 /************************************************************
  *             Callbacks for a non-Modal Dialog             *
  ************************************************************/
