@@ -145,6 +145,79 @@ static void gdc_add_tag_markings(GncDenseCal *cal, guint tag);
 static void gdc_add_markings(GncDenseCal *cal);
 static void gdc_remove_markings(GncDenseCal *cal);
 
+typedef struct _gdc_month_coords
+{
+    gint x, y;
+} gdc_month_coords;
+
+struct _GncDenseCal
+{
+    GtkBox widget;
+
+    GtkComboBox *view_options;
+    GtkDrawingArea *cal_drawing_area;
+
+    cairo_surface_t *surface;
+
+    gboolean initialized;
+
+    gboolean showPopup;
+    GtkWindow *transPopup;
+    gint screen_width;
+    gint screen_height;
+    gint doc;
+
+    gint min_x_scale;
+    gint min_y_scale;
+
+    gint x_scale;
+    gint y_scale;
+
+    gint numMonths;
+    gint monthsPerCol;
+    gint num_weeks; /* computed */
+
+    GDateMonth month;
+    guint year;
+    gint firstOfMonthOffset;
+
+    gint leftPadding;
+    gint topPadding;
+
+    gdc_month_coords monthPositions[12];
+
+    guint label_width;
+    guint label_height;
+    gint dayLabelHeight;
+
+    GncDenseCalModel *model;
+
+    guint lastMarkTag;
+
+    gint week_starts_monday;
+
+    /**
+     * A GList of gdc_mark_data structs, one for each active/valid markTag.
+     **/
+    GList *markData;
+    int numMarks;
+    /* array of GList*s of per-cell markings. */
+    GList **marks;
+
+    int disposed; /* private */
+};
+
+typedef struct _gdc_mark_data
+{
+    gchar *name;
+    gchar *info;
+    guint tag;
+    /**
+     * A GList of the dcal->marks indexes containing this mark.
+     **/
+    GList *ourMarks;
+} gdc_mark_data;
+
 G_DEFINE_TYPE (GncDenseCal, gnc_dense_cal, GTK_TYPE_BOX)
 
 #define MONTH_NAME_BUFSIZE 10
