@@ -252,7 +252,9 @@ public:
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
         auto widget{GTK_TEXT_VIEW(get_widget())};
-        option.set_value(std::string{xxxgtk_textview_get_text(widget)});
+        auto str{xxxgtk_textview_get_text(widget)};
+        option.set_value(std::string{str});
+        g_free (str);
     }
 };
 
@@ -1080,7 +1082,8 @@ public:
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
         auto widget{GNC_ACCOUNT_SEL(get_widget())};
-        option.set_value(qof_instance_cast((gnc_account_sel_get_account(widget))));
+// Must cast it to const Account* to get the template specialization to recognize it.
+        option.set_value(static_cast<const Account*>(gnc_account_sel_get_account(widget)));
     }
 };
 
@@ -1150,10 +1153,12 @@ class GncGtkListUIItem : public GncOptionGtkUIItem
 public:
     GncGtkListUIItem(GtkWidget* widget) :
         GncOptionGtkUIItem{widget, GncOptionUIType::LIST} {}
+
     void set_ui_item_from_option(GncOption& option) noexcept override
     {
         auto widget{GTK_TREE_VIEW(get_widget())};
         auto selection{gtk_tree_view_get_selection(widget)};
+        gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
         g_signal_handlers_block_by_func(selection, (gpointer)list_changed_cb, &option);
         gtk_tree_selection_unselect_all(selection);
         for (auto index : option.get_value<GncMultichoiceOptionIndexVec>())
@@ -1164,20 +1169,20 @@ public:
         }
         g_signal_handlers_unblock_by_func(selection, (gpointer)list_changed_cb, &option);
     }
+
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
         auto widget{GTK_TREE_VIEW(get_widget())};
         auto selection{gtk_tree_view_get_selection(widget)};
-        auto rows{option.num_permissible_values()};
+        auto selected_rows{gtk_tree_selection_get_selected_rows(selection, nullptr)};
         GncMultichoiceOptionIndexVec vec;
-        for (size_t row = 0; row < rows; ++row)
+        for (auto row = selected_rows; row; row = g_list_next(row))
         {
-            auto path{gtk_tree_path_new_from_indices(row, -1)};
-            auto selected{gtk_tree_selection_path_is_selected(selection, path)};
-            gtk_tree_path_free(path);
-            if (selected)
-                vec.push_back(row);
+            auto path{static_cast<GtkTreePath*>(row->data)};
+            auto indices{gtk_tree_path_get_indices(path)};
+            vec.push_back(*indices);
         }
+        g_list_free_full(selected_rows, (GDestroyNotify)gtk_tree_path_free);
         option.set_value(vec);
     }
 };
@@ -1677,13 +1682,21 @@ public:
     void set_ui_item_from_option(GncOption& option) noexcept override
     {
         auto widget{GNC_DATE_FORMAT(get_widget())};
-        gnc_date_format_set_custom(widget,
-                                   option.get_value<std::string>().c_str());
+        auto [format, months, years, custom] = option.get_value<GncOptionDateFormat>();
+        gnc_date_format_set_format(widget, format);
+        gnc_date_format_set_months(widget, months);
+        gnc_date_format_set_years(widget, years);
+        gnc_date_format_set_custom(widget, custom.c_str());
     }
     void set_option_from_ui_item(GncOption& option) noexcept override
     {
         auto widget{GNC_DATE_FORMAT(get_widget())};
-        option.set_value(std::string{gnc_date_format_get_custom(widget)});
+        GncOptionDateFormat format{
+            gnc_date_format_get_format(widget),
+            gnc_date_format_get_months(widget),
+            gnc_date_format_get_years(widget),
+            gnc_date_format_get_custom(widget)};
+        option.set_value(format);
     }
 };
 
