@@ -42,12 +42,8 @@
 
 /** The debugging module that this .o belongs to.  */
 static QofLogModule log_module = GNC_MOD_GUI;
-/** A pointer to the parent class of a plugin page. */
-static gpointer parent_class = NULL;
 
-static void gnc_plugin_page_class_init (GncPluginPageClass *klass);
-static void gnc_plugin_page_init       (GncPluginPage *plugin_page,
-                                        void *data);
+static void gnc_plugin_page_constructed (GObject *object);
 static void gnc_plugin_page_finalize   (GObject *object);
 static void gnc_plugin_page_set_property (GObject      *object,
                                           guint         prop_id,
@@ -111,7 +107,7 @@ typedef struct _GncPluginPagePrivate
 
 } GncPluginPagePrivate;
 
-GNC_DEFINE_TYPE_WITH_CODE(GncPluginPage, gnc_plugin_page, G_TYPE_OBJECT,
+G_DEFINE_TYPE_WITH_CODE(GncPluginPage, gnc_plugin_page, G_TYPE_OBJECT,
                 G_ADD_PRIVATE(GncPluginPage))
 
 #define GNC_PLUGIN_PAGE_GET_PRIVATE(o)  \
@@ -356,7 +352,7 @@ gnc_plugin_page_class_init (GncPluginPageClass *klass)
 {
     GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
-    parent_class = g_type_class_peek_parent (klass);
+    gobject_class->constructed = gnc_plugin_page_constructed;
     gobject_class->finalize = gnc_plugin_page_finalize;
     gobject_class->set_property = gnc_plugin_page_set_property;
     gobject_class->get_property = gnc_plugin_page_get_property;
@@ -457,21 +453,14 @@ gnc_plugin_page_class_init (GncPluginPageClass *klass)
 
 
 /** Initialize a new instance of a gnucash content plugin.  This
- *  function initializes the object private storage space, and adds
- *  the object to the tracking system.
+ *  function initializes the object private storage space.
  *
  *  @param page The new object instance created by the object system.
- *
- *  @param klass A pointer to the class data structure for this
- *  object. */
+ *  */
 static void
-gnc_plugin_page_init (GncPluginPage *page, void *data)
+gnc_plugin_page_init (GncPluginPage *page)
 {
-    GncPluginPagePrivate *priv;
-
-    GncPluginPageClass *klass = (GncPluginPageClass*)data;
-
-    priv = GNC_PLUGIN_PAGE_GET_PRIVATE(page);
+    GncPluginPagePrivate *priv = GNC_PLUGIN_PAGE_GET_PRIVATE(page);
     priv->page_name   = NULL;
     priv->page_color  = NULL;
     priv->page_changed_id = 0;
@@ -480,11 +469,21 @@ gnc_plugin_page_init (GncPluginPage *page, void *data)
 
     page->window      = NULL;
     page->summarybar  = NULL;
-
-    gnc_gobject_tracking_remember (G_OBJECT(page),
-                                   G_OBJECT_CLASS(klass));
 }
 
+/** The object has been fully constructed.
+ * This function adds the object to the tracking system.
+ *
+ *  @param obj The new object instance created by the object
+ *  system.
+ */
+ static void
+gnc_plugin_page_constructed (GObject *obj)
+{
+    gnc_gobject_tracking_remember(obj);
+
+    G_OBJECT_CLASS (gnc_plugin_page_parent_class)->constructed (obj);
+}
 
 /** Finalize the gnucash plugin object.  This function is called from
  *  the G_Object level to complete the destruction of the object.  It
@@ -524,10 +523,13 @@ gnc_plugin_page_finalize (GObject *object)
         priv->books = NULL;
     }
 
+    if (priv->builder)
+        g_object_unref (priv->builder);
+
     page->window = NULL; // Don't need to free it.
 
     gnc_gobject_tracking_forget (object);
-    G_OBJECT_CLASS(parent_class)->finalize (object);
+    G_OBJECT_CLASS(gnc_plugin_page_parent_class)->finalize (object);
 }
 
 /************************************************************/
@@ -889,7 +891,8 @@ gnc_plugin_page_inserted_cb (GncPluginPage *page, gpointer user_data)
                                               page);
 
     // on initial load try and set the page focus
-    (GNC_PLUGIN_PAGE_GET_CLASS(page)->focus_page)(page, TRUE);
+    if (!gnc_main_window_is_restoring_pages (GNC_MAIN_WINDOW(page->window)))
+        (GNC_PLUGIN_PAGE_GET_CLASS(page)->focus_page)(page, TRUE);
 }
 
 
