@@ -178,6 +178,7 @@ static void gnc_ui_to_vendor (VendorWindow *vw, GncVendor *vendor)
 
     gncVendorCommitEdit (vendor);
     gnc_resume_gui_refresh ();
+    g_free (text);
 }
 
 static gboolean check_entry_nonempty (GtkWidget *entry,
@@ -239,7 +240,7 @@ void
 gnc_vendor_window_help_cb (GtkWidget *widget, gpointer data)
 {
     VendorWindow *vw = data;
-    gnc_gnome_help (GTK_WINDOW(vw->dialog), HF_HELP, HL_USAGE_VENDOR);
+    gnc_gnome_help (GTK_WINDOW(vw->dialog), DF_MANUAL, DL_USAGE_VENDOR);
 }
 
 void
@@ -267,30 +268,13 @@ void
 gnc_vendor_name_changed_cb (GtkWidget *widget, gpointer data)
 {
     VendorWindow *vw = data;
-    char *name, *id, *fullname, *title;
-
     if (!vw)
         return;
 
-    name = gtk_editable_get_chars (GTK_EDITABLE (vw->company_entry), 0, -1);
-    if (!name || *name == '\0')
-        name = g_strdup (_("<No name>"));
-
-    id = gtk_editable_get_chars (GTK_EDITABLE (vw->id_entry), 0, -1);
-
-    fullname = g_strconcat (name, " (", id, ")", (char *)NULL);
-
-    if (vw->dialog_type == EDIT_VENDOR)
-        title = g_strconcat (_("Edit Vendor"), " - ", fullname, (char *)NULL);
-    else
-        title = g_strconcat (_("New Vendor"), " - ", fullname, (char *)NULL);
-
-    gtk_window_set_title (GTK_WINDOW (vw->dialog), title);
-
-    g_free (name);
-    g_free (id);
-    g_free (fullname);
-    g_free (title);
+    gnc_owner_window_set_title (GTK_WINDOW (vw->dialog),
+                                (vw->dialog_type == EDIT_VENDOR) ?
+                                _("Edit Vendor") : _("New Vendor"),
+                                vw->company_entry, vw->id_entry);
 }
 
 void
