@@ -124,7 +124,6 @@ static void gsr_default_doclink_from_sheet_handler ( GNCSplitReg *w );
 static void gsr_emit_simple_signal       ( GNCSplitReg *gsr, const char *sigName );
 static void gsr_emit_help_changed        ( GnucashRegister *reg, gpointer user_data );
 static void gsr_emit_show_popup_menu     ( GnucashRegister *reg, gpointer user_data );
-static void gsr_emit_include_date_signal ( GNCSplitReg *gsr, time64 date );
 
 void gnc_split_reg_cut_cb(GtkWidget *w, gpointer data);
 void gnc_split_reg_copy_cb(GtkWidget *w, gpointer data);
@@ -172,41 +171,13 @@ void gnc_split_reg_size_allocate( GtkWidget *widget,
                                   gpointer user_data );
 
 
-static void gnc_split_reg_class_init( GNCSplitRegClass *klass );
-static void gnc_split_reg_init( GNCSplitReg *gsr );
 static void gnc_split_reg_init2( GNCSplitReg *gsr );
 void gnc_split_reg_dispose(GObject *obj);
 
 FROM_STRING_FUNC(SortType, ENUM_LIST_SORTTYPE)
 AS_STRING_FUNC(SortType, ENUM_LIST_SORTTYPE)
 
-GType
-gnc_split_reg_get_type( void )
-{
-    static GType gnc_split_reg_type = 0;
-
-    if (!gnc_split_reg_type)
-    {
-        GTypeInfo type_info =
-        {
-            sizeof(GNCSplitRegClass),      /* class_size */
-            NULL,               /* base_init */
-            NULL,               /* base_finalize */
-            (GClassInitFunc)gnc_split_reg_class_init,
-            NULL,               /* class_finalize */
-            NULL,               /* class_data */
-            sizeof(GNCSplitReg),        /* */
-            0,                  /* n_preallocs */
-            (GInstanceInitFunc)gnc_split_reg_init,
-        };
-
-        gnc_split_reg_type = g_type_register_static( GTK_TYPE_BOX,
-                             "GNCSplitReg",
-                             &type_info, 0 );
-    }
-
-    return gnc_split_reg_type;
-}
+G_DEFINE_TYPE (GNCSplitReg, gnc_split_reg, GTK_TYPE_BOX)
 
 /* SIGNALS */
 enum gnc_split_reg_signal_enum
@@ -269,13 +240,12 @@ gnc_split_reg_class_init( GNCSplitRegClass *klass )
         { REVERSE_TXN_SIGNAL,     "reverse_txn",     G_STRUCT_OFFSET( GNCSplitRegClass, reverse_txn_cb ) },
         { HELP_CHANGED_SIGNAL,    "help-changed",    G_STRUCT_OFFSET( GNCSplitRegClass, help_changed_cb ) },
         { SHOW_POPUP_MENU_SIGNAL, "show-popup-menu", G_STRUCT_OFFSET( GNCSplitRegClass, show_popup_menu_cb ) },
-        { INCLUDE_DATE_SIGNAL,    "include-date",    G_STRUCT_OFFSET( GNCSplitRegClass, include_date_cb ) },
         { LAST_SIGNAL, NULL, 0 }
     };
 
     object_class = (GObjectClass*) klass;
 
-    for ( i = 0; signals[i].s != INCLUDE_DATE_SIGNAL; i++ )
+    for ( i = 0; signals[i].s != LAST_SIGNAL; i++ )
     {
         gnc_split_reg_signals[ signals[i].s ] =
             g_signal_new( signals[i].signal_name,
@@ -286,18 +256,6 @@ gnc_split_reg_class_init( GNCSplitRegClass *klass )
                           g_cclosure_marshal_VOID__VOID,
                           G_TYPE_NONE, 0 );
     }
-    /* Setup the non-default-marshalled signals; 'i' is still valid, here. */
-    /* "include-date" */
-    gnc_split_reg_signals[ INCLUDE_DATE_SIGNAL ] =
-        g_signal_new( "include-date",
-                      G_TYPE_FROM_CLASS(object_class),
-                      G_SIGNAL_RUN_LAST,
-                      signals[i++].defaultOffset,
-                      NULL, NULL,
-                      g_cclosure_marshal_VOID__INT, /* time64 == int */
-                      G_TYPE_NONE, 1, G_TYPE_INT );
-
-    g_assert( i == LAST_SIGNAL );
 
     /* Setup the default handlers. */
     klass->enter_ent_cb    = gsr_default_enter_handler;
@@ -321,7 +279,6 @@ gnc_split_reg_class_init( GNCSplitRegClass *klass )
 
     klass->help_changed_cb = NULL;
     klass->show_popup_menu_cb = NULL;
-    klass->include_date_cb = NULL;
 
     object_class->dispose = gnc_split_reg_dispose;
 }
@@ -411,7 +368,6 @@ static void
 gsr_move_sort_and_filter_to_state_file (GNCSplitReg *gsr, GKeyFile* state_file, const gchar *state_section)
 {
     GNCLedgerDisplayType ledger_type;
-    GNCLedgerDisplay* ld;
 
     // Look for any old kvp entries and add them to .gcm file
     ledger_type = gnc_ledger_display_type (gsr->ledger);
@@ -454,22 +410,36 @@ gsr_move_sort_and_filter_to_state_file (GNCSplitReg *gsr, GKeyFile* state_file,
     }
 }
 
+gchar *
+gsr_get_register_state_section (GNCSplitReg *gsr)
+{
+    GNCLedgerDisplayType ledger_type = gnc_ledger_display_type (gsr->ledger);
+    Account *account = gnc_ledger_display_leader (gsr->ledger);
+    const GncGUID *guid = xaccAccountGetGUID (account);
+    gchar guidstr[GUID_ENCODING_LENGTH+1];
+    gchar *register_state_section;
+
+    guid_to_string_buff (guid, guidstr);
+
+    if (ledger_type == LD_SUBACCOUNT)
+        register_state_section = g_strconcat (STATE_SECTION_REG_PREFIX, " ", guidstr, "+", NULL);
+    else
+        register_state_section = g_strconcat (STATE_SECTION_REG_PREFIX, " ", guidstr, NULL);
+
+    return register_state_section;
+}
+
 static
 void
 gsr_create_table( GNCSplitReg *gsr )
 {
     GtkWidget *register_widget = NULL;
     SplitRegister *sr = NULL;
-
-    Account * account = gnc_ledger_display_leader(gsr->ledger);
-    const GncGUID * guid = xaccAccountGetGUID(account);
-    gchar guidstr[GUID_ENCODING_LENGTH+1];
     GKeyFile* state_file = gnc_state_get_current();
     gchar *register_state_section;
 
-    guid_to_string_buff (guid, guidstr);
-
-    register_state_section = g_strconcat (STATE_SECTION_REG_PREFIX, " ", guidstr, NULL);
+    /* register_state_section is used to store per register state: column widths, sort order,... */
+    register_state_section = gsr_get_register_state_section (gsr);
 
     ENTER("gsr=%p", gsr);
 
@@ -786,29 +756,22 @@ static void
 gnc_split_reg_ld_destroy( GNCLedgerDisplay *ledger )
 {
     GNCSplitReg *gsr = gnc_ledger_display_get_user_data( ledger );
-    Account * account = gnc_ledger_display_leader(ledger);
-    const GncGUID * guid = xaccAccountGetGUID(account);
-    gchar guidstr[GUID_ENCODING_LENGTH+1];
-    gchar *state_section;
-    guid_to_string_buff(guid, guidstr);
-
-    state_section = g_strconcat (STATE_SECTION_REG_PREFIX, " ", guidstr, NULL);
 
     if (gsr)
     {
-        SplitRegister *reg;
-
-        reg = gnc_ledger_display_get_split_register (ledger);
+        /* register_state_section is used to store per register state: column widths, sort order,... */
+        gchar *register_state_section = gsr_get_register_state_section (gsr);
+        SplitRegister *reg = gnc_ledger_display_get_split_register (ledger);
 
         if (reg && reg->table)
-            gnc_table_save_state (reg->table, state_section);
+            gnc_table_save_state (reg->table, register_state_section);
 
         /*
          * Don't destroy the window here any more.  The register no longer
          * owns it.
          */
+        g_free (register_state_section);
     }
-    g_free (state_section);
 
     gnc_ledger_display_set_user_data (ledger, NULL);
     g_object_unref (gsr);
@@ -1368,7 +1331,6 @@ gsr_default_doclink_remove_handler (GNCSplitReg *gsr)
 static void
 gsr_default_doclink_from_sheet_handler (GNCSplitReg *gsr)
 {
-    CursorClass cursor_class;
     SplitRegister *reg = gnc_ledger_display_get_split_register (gsr->ledger);
     Transaction *trans;
     Split *split;
@@ -1731,18 +1693,11 @@ gnc_split_reg_clear_filter_for_split (GNCSplitReg *gsr, Split *split)
 void
 gnc_split_reg_jump_to_split(GNCSplitReg *gsr, Split *split)
 {
-    Transaction *trans;
-    VirtualCellLocation vcell_loc;
-    SplitRegister *reg;
-
     if (!gsr) return;
 
-    trans = xaccSplitGetParent(split);
-
-    gsr_emit_include_date_signal( gsr, xaccTransGetDate(trans) );
-
-    reg = gnc_ledger_display_get_split_register( gsr->ledger );
+    SplitRegister *reg = gnc_ledger_display_get_split_register( gsr->ledger );
 
+    VirtualCellLocation vcell_loc;
     if (gnc_split_register_get_split_virt_loc(reg, split, &vcell_loc))
         gnucash_register_goto_virt_cell( gsr->reg, vcell_loc );
 
@@ -1755,17 +1710,11 @@ gnc_split_reg_jump_to_split(GNCSplitReg *gsr, Split *split)
 void
 gnc_split_reg_jump_to_split_amount(GNCSplitReg *gsr, Split *split)
 {
-    VirtualLocation virt_loc;
-    SplitRegister *reg;
-    Transaction *trans;
-
     if (!gsr) return;
 
-    trans = xaccSplitGetParent(split);
-    gsr_emit_include_date_signal( gsr, xaccTransGetDate(trans) );
-
-    reg = gnc_ledger_display_get_split_register (gsr->ledger);
+    SplitRegister *reg = gnc_ledger_display_get_split_register (gsr->ledger);
 
+    VirtualLocation virt_loc;
     if (gnc_split_register_get_split_amount_virt_loc (reg, split, &virt_loc))
         gnucash_register_goto_virt_loc (gsr->reg, virt_loc);
 
@@ -2145,9 +2094,14 @@ gnc_split_reg_set_sort_reversed(GNCSplitReg *gsr, gboolean rev, gboolean refresh
      *       In other words, qof_query_set_sort_increasing should
      *       always use the inverse of rev.
      */
+    SplitRegister *reg = gnc_ledger_display_get_split_register (gsr->ledger);
     Query *query = gnc_ledger_display_get_query( gsr->ledger );
+
+    gnc_split_register_set_reverse_sort (reg, rev);
+
     qof_query_set_sort_increasing (query, !rev, !rev, !rev);
     gsr->sort_rev = rev;
+
     if (refresh)
         gnc_ledger_display_refresh( gsr->ledger );
 }
@@ -2155,13 +2109,9 @@ gnc_split_reg_set_sort_reversed(GNCSplitReg *gsr, gboolean rev, gboolean refresh
 static gboolean
 gnc_split_reg_record (GNCSplitReg *gsr)
 {
-    SplitRegister *reg;
-    Transaction *trans;
-
     ENTER("gsr=%p", gsr);
 
-    reg = gnc_ledger_display_get_split_register (gsr->ledger);
-    trans = gnc_split_register_get_current_trans (reg);
+    SplitRegister *reg = gnc_ledger_display_get_split_register (gsr->ledger);
 
     if (!gnc_split_register_save (reg, TRUE))
     {
@@ -2169,8 +2119,6 @@ gnc_split_reg_record (GNCSplitReg *gsr)
         return FALSE;
     }
 
-    gsr_emit_include_date_signal( gsr, xaccTransGetDate(trans) );
-
     /* Explicit redraw shouldn't be needed,
      * since gui_refresh events should handle this. */
     /* gnc_split_register_redraw (reg); */
@@ -2213,7 +2161,7 @@ gnc_split_reg_enter( GNCSplitReg *gsr, gboolean next_transaction )
     goto_blank = gnc_prefs_get_bool(GNC_PREFS_GROUP_GENERAL_REGISTER,
                                     GNC_PREF_ENTER_MOVES_TO_END);
 
-    /* If we are in single or double line mode and we hit enter
+    /* If we are in single or double line view and we hit enter
      * on the blank split, go to the blank split instead of the
      * next row. This prevents the cursor from jumping around
      * when you are entering transactions. */
@@ -2452,7 +2400,6 @@ gtk_callback_bug_workaround (gpointer argp)
     GNCLedgerDisplayType ledger_type = gnc_ledger_display_type (args->gsr->ledger);
     Account *acc = gnc_ledger_display_leader (args->gsr->ledger);
     const gchar *acc_name = NULL;
-    gchar *tmp = NULL;
 
     if (acc)
     {
@@ -2502,7 +2449,6 @@ gnc_split_reg_determine_read_only( GNCSplitReg *gsr, gboolean show_dialog )
 
     if ( !gsr->read_only )
     {
-        dialog_args *args;
         char *string = NULL;
         reg = gnc_ledger_display_get_split_register( gsr->ledger );
         if(reg->mismatched_commodities)
@@ -2539,12 +2485,15 @@ gnc_split_reg_determine_read_only( GNCSplitReg *gsr, gboolean show_dialog )
             }
         }
         gsr->read_only = TRUE;
-        /* Put up a warning dialog */
-        args = g_malloc(sizeof(dialog_args));
-        args->string = string;
-        args->gsr = gsr;
         if (show_dialog)
+        {
+            /* Put up a warning dialog */
+            dialog_args *args = g_malloc(sizeof(dialog_args));
+            args->string = string;
+            args->gsr = gsr;
+
             g_timeout_add (250, gtk_callback_bug_workaround, args); /* 0.25 seconds */
+        }
     }
 
     /* Make the contents immutable */
@@ -2580,13 +2529,6 @@ gsr_emit_show_popup_menu( GnucashRegister *reg, gpointer user_data )
     gsr_emit_simple_signal( (GNCSplitReg*)user_data, "show-popup-menu" );
 }
 
-static
-void
-gsr_emit_include_date_signal( GNCSplitReg *gsr, time64 date )
-{
-    g_signal_emit_by_name( gsr, "include-date", date, NULL );
-}
-
 static
 void
 gsr_emit_simple_signal( GNCSplitReg *gsr, const char *sigName )
