@@ -128,26 +128,18 @@ gnc_import_TransInfo_get_match_list (const GNCImportTransInfo *info)
     return info->match_list;
 }
 
-static void
-gnc_import_TransInfo_set_match_list (GNCImportTransInfo *info, GList* match_list)
+void
+gnc_import_TransInfo_remove_top_match (GNCImportTransInfo *info)
 {
-    g_assert (info);
-    info->match_list = match_list;
-    if (match_list)
-        info->selected_match_info.selected_match = static_cast<GNCImportMatchInfo*>(match_list->data);
+    g_return_if_fail (info);
+    info->match_list = g_list_remove (info->match_list, static_cast<gpointer>(info->match_list->data));
+    if (info->match_list)
+        info->selected_match_info.selected_match = static_cast<GNCImportMatchInfo*>(info->match_list->data);
     else
     {
         info->selected_match_info.selected_match = nullptr;
         gnc_import_TransInfo_set_action (info, GNCImport_ADD);
-    }
-}
-
-void
-gnc_import_TransInfo_remove_top_match (GNCImportTransInfo *info)
-{
-    GList* match_trans = gnc_import_TransInfo_get_match_list (info);
-    match_trans = g_list_remove (match_trans, static_cast<gpointer>(match_trans->data));
-    gnc_import_TransInfo_set_match_list (info, match_trans);
+    };
 }
 
 Transaction *
@@ -348,7 +340,7 @@ void gnc_import_TransInfo_delete (GNCImportTransInfo *info)
 {
     if (info)
     {
-        g_list_free (info->match_list);
+        g_list_free_full (info->match_list, g_free);
         /*If the transaction exists and is still open, it must be destroyed*/
         if (xaccTransIsOpen(info->trans))
         {
@@ -1041,15 +1033,6 @@ gboolean gnc_import_exists_online_id (Transaction *trans, GHashTable* acct_id_ha
     }
 
     auto online_id_exists = g_hash_table_contains (online_id_hash, source_online_id);
-    
-    /* If it does, abort the process for this transaction, since it is
-       already in the system. */
-    if (online_id_exists)
-    {
-        DEBUG("%s", "Transaction with same online ID exists, destroying current transaction");
-        xaccTransDestroy(trans);
-        xaccTransCommitEdit(trans);
-    }
     g_free (source_online_id);
     return online_id_exists;
 }
