@@ -1,7 +1,6 @@
 #include <glib.h>
 #include <gtk/gtk.h> /* for references in import-backend.h */
 
-extern "C" {
 #include <config.h>
 #include <unittest-support.h>
 
@@ -9,7 +8,6 @@ extern "C" {
 #include "import-pending-matches.h"
 #include "Split.h"
 #include "test-engine-stuff.h"
-}
 
 static const gchar *suitename = "/import-export/import-pending-matches";
 
@@ -131,4 +129,6 @@ main (int argc, char *argv[])
     result =  g_test_run();
 
     qof_close();
+
+    return result;
 }
