@@ -70,8 +70,6 @@ enum
 
 /* This static indicates the debugging module that this .o belongs to. */
 static QofLogModule log_module = G_LOG_DOMAIN;
-static GtkLayout *sheet_parent_class;
-
 
 /** Prototypes *********************************************************/
 
@@ -91,6 +89,7 @@ gboolean gnucash_sheet_draw_cb (GtkWidget *widget, cairo_t *cr,
 
 /** Implementation *****************************************************/
 
+G_DEFINE_TYPE (GnucashSheet, gnucash_sheet, GTK_TYPE_LAYOUT);
 
 /* gtk_editable_set_position sets both current_pos and selection_bound to the
  * supplied value. gtk_editable_select_region(start, end) sets current_pos to
@@ -145,19 +144,6 @@ gnucash_sheet_set_position (GnucashSheet* sheet, int pos)
     gnucash_sheet_set_position_and_selection (sheet, pos, pos, pos);
 }
 
-static inline void
-gnucash_sheet_get_selection (GnucashSheet *sheet, int *start, int *end)
-{
-    *start = sheet->pos;
-    *end = sheet->bound;
-}
-
-static inline void
-gnucash_sheet_clear_selection (GnucashSheet *sheet)
-{
-    gnucash_sheet_set_selection (sheet, sheet->pos, sheet->pos);
-}
-
 static inline void
 gnucash_sheet_set_entry_value (GnucashSheet *sheet, const char* value)
 {
@@ -362,7 +348,6 @@ gnucash_sheet_activate_cursor_cell (GnucashSheet *sheet,
     Table *table = sheet->table;
     VirtualLocation virt_loc;
     SheetBlockStyle *style;
-    GtkEditable *editable;
     int cursor_pos, start_sel, end_sel;
     gboolean allow_edits;
 
@@ -384,8 +369,6 @@ gnucash_sheet_activate_cursor_cell (GnucashSheet *sheet,
     if (strcmp (style->cursor->cursor_name, CURSOR_HEADER) == 0)
         return;
 
-    editable = GTK_EDITABLE(sheet->entry);
-
     cursor_pos = -1;
     start_sel = 0;
     end_sel = 0;
@@ -421,7 +404,6 @@ gnucash_sheet_activate_cursor_cell (GnucashSheet *sheet,
             GdkRectangle rect;
             gint x, y, width, height;
             gint index = 0, trailing = 0;
-            gboolean result;
             gint x_offset = 0;
 
             if (text && *text)
@@ -819,8 +801,7 @@ gnucash_sheet_finalize (GObject *object)
 
     g_object_unref (sheet->cursor);
 
-    if (G_OBJECT_CLASS(sheet_parent_class)->finalize)
-        (*G_OBJECT_CLASS(sheet_parent_class)->finalize)(object);
+    (*G_OBJECT_CLASS(gnucash_sheet_parent_class)->finalize)(object);
 }
 
 
@@ -1226,8 +1207,8 @@ gnucash_sheet_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 
     ENTER("widget=%p, allocation=%p", widget, allocation);
 
-    if (GTK_WIDGET_CLASS(sheet_parent_class)->size_allocate)
-        (*GTK_WIDGET_CLASS(sheet_parent_class)->size_allocate)
+    if (GTK_WIDGET_CLASS(gnucash_sheet_parent_class)->size_allocate)
+        (*GTK_WIDGET_CLASS(gnucash_sheet_parent_class)->size_allocate)
         (widget, allocation);
 
     if (allocation->height == sheet->window_height &&
@@ -1271,8 +1252,8 @@ gnucash_sheet_focus_in_event (GtkWidget *widget, GdkEventFocus *event)
 {
     GnucashSheet *sheet = GNUCASH_SHEET(widget);
 
-    if (GTK_WIDGET_CLASS(sheet_parent_class)->focus_in_event)
-        (*GTK_WIDGET_CLASS(sheet_parent_class)->focus_in_event)
+    if (GTK_WIDGET_CLASS(gnucash_sheet_parent_class)->focus_in_event)
+        (*GTK_WIDGET_CLASS(gnucash_sheet_parent_class)->focus_in_event)
         (widget, event);
 
     gnc_item_edit_focus_in (GNC_ITEM_EDIT(sheet->item_editor));
@@ -1285,8 +1266,8 @@ gnucash_sheet_focus_out_event (GtkWidget *widget, GdkEventFocus *event)
 {
     GnucashSheet *sheet = GNUCASH_SHEET(widget);
 
-    if (GTK_WIDGET_CLASS(sheet_parent_class)->focus_out_event)
-        (*GTK_WIDGET_CLASS(sheet_parent_class)->focus_out_event)
+    if (GTK_WIDGET_CLASS(gnucash_sheet_parent_class)->focus_out_event)
+        (*GTK_WIDGET_CLASS(gnucash_sheet_parent_class)->focus_out_event)
         (widget, event);
 
     gnc_item_edit_focus_out (GNC_ITEM_EDIT(sheet->item_editor));
@@ -1379,7 +1360,6 @@ gnucash_scroll_event (GtkWidget *widget, GdkEventScroll *event)
     GnucashSheet *sheet;
     GtkAdjustment *vadj;
     gfloat h_value, v_value;
-    int direction;
 
     g_return_val_if_fail (widget != NULL, TRUE);
     g_return_val_if_fail (GNUCASH_IS_SHEET(widget), TRUE);
@@ -1410,7 +1390,7 @@ gnucash_scroll_event (GtkWidget *widget, GdkEventScroll *event)
 #if defined MAC_INTEGRATION
         v_value += event->delta_y;
 #else
-        direction = event->delta_y > 0 ? 1 : event->delta_y < 0 ? -1 : 0;
+        int direction = event->delta_y > 0 ? 1 : event->delta_y < 0 ? -1 : 0;
         v_value += gtk_adjustment_get_step_increment (vadj) * direction;
 #endif
         break;
@@ -1811,7 +1791,6 @@ gnucash_sheet_key_press_event_internal (GtkWidget *widget, GdkEventKey *event)
     VirtualLocation cur_virt_loc;
     VirtualLocation new_virt_loc;
     gncTableTraversalDir direction = 0;
-    int distance;
     GdkModifierType modifiers = gtk_accelerator_get_default_mod_mask ();
 
     g_return_val_if_fail (widget != NULL, TRUE);
@@ -1889,14 +1868,12 @@ static gint
 gnucash_sheet_key_press_event (GtkWidget *widget, GdkEventKey *event)
 {
     GnucashSheet *sheet;
-    GtkEditable *editable = NULL;
 
     g_return_val_if_fail (widget != NULL, TRUE);
     g_return_val_if_fail (GNUCASH_IS_SHEET(widget), TRUE);
     g_return_val_if_fail (event != NULL, TRUE);
 
     sheet = GNUCASH_SHEET(widget);
-    editable = GTK_EDITABLE(sheet->entry);
     /* bug#60582 comment#27 2
            save shift state to enable <shift minus> and <shift equal>
        bug#618434
@@ -1917,8 +1894,6 @@ gnucash_sheet_key_press_event (GtkWidget *widget, GdkEventKey *event)
 static gint
 gnucash_sheet_key_release_event (GtkWidget *widget, GdkEventKey *event)
 {
-    GnucashSheet *sheet;
-
     g_return_val_if_fail (widget != NULL, TRUE);
     g_return_val_if_fail (GNUCASH_IS_SHEET(widget), TRUE);
     g_return_val_if_fail (event != NULL, TRUE);
@@ -2352,8 +2327,6 @@ gnucash_sheet_class_init (GnucashSheetClass *klass)
 
     gtk_widget_class_set_css_name (GTK_WIDGET_CLASS(klass), "gnc-id-sheet");
 
-    sheet_parent_class = g_type_class_peek_parent (klass);
-
     /* Method override */
     gobject_class->finalize = gnucash_sheet_finalize;
 
@@ -2416,37 +2389,6 @@ gnucash_sheet_init (GnucashSheet *sheet)
     sheet->bound = sheet->pos = 0;
 }
 
-
-GType
-gnucash_sheet_get_type (void)
-{
-    static GType gnucash_sheet_type = 0;
-
-    if (!gnucash_sheet_type)
-    {
-        static const GTypeInfo gnucash_sheet_info =
-        {
-            sizeof (GnucashSheetClass),
-            NULL,       /* base_init */
-            NULL,       /* base_finalize */
-            (GClassInitFunc) gnucash_sheet_class_init,
-            NULL,       /* class_finalize */
-            NULL,       /* class_data */
-            sizeof (GnucashSheet),
-            0,      /* n_preallocs */
-            (GInstanceInitFunc) gnucash_sheet_init
-        };
-
-        gnucash_sheet_type =
-            g_type_register_static (GTK_TYPE_LAYOUT,
-                                    "GnucashSheet",
-                                    &gnucash_sheet_info, 0);
-    }
-
-    return gnucash_sheet_type;
-}
-
-
 static gboolean
 gnucash_sheet_tooltip (GtkWidget  *widget, gint x, gint y,
                        gboolean    keyboard_mode,
