@@ -27,6 +27,10 @@
 
 #include <glib.h>
 #include <libguile.h>
+#ifdef __cplusplus
+extern "C"
+{
+#endif
 
 #define SAVED_REPORTS_FILE "saved-reports-2.8"
 #define SAVED_REPORTS_FILE_OLD_REV "saved-reports-2.4"
@@ -35,36 +39,54 @@
  *
  *  Should be called once before using any of its features.
  */
-void gnc_report_init (void);
+void gnc_report_init(void);
 
 
-gboolean gnc_run_report (gint report_id, char ** data);
-gboolean gnc_run_report_with_error_handling (gint report_id,
-                                             gchar **data,
-                                             gchar **errmsg);
-gboolean gnc_run_report_id_string (const char * id_string, char **data);
-gboolean gnc_run_report_id_string_with_error_handling (const char * id_string,
-                                                       char **data,
-                                                       gchar **errmsg);
+gboolean gnc_run_report_with_error_handling(gint report_id,
+                                            gchar** data,
+                                            gchar** errmsg);
+
+gboolean gnc_run_report_id_string_with_error_handling(const char* id_string,
+                                                      char** data,
+                                                      gchar** errmsg);
 
 /**
  * @param report The SCM version of the report.
  * @return a caller-owned copy of the name of the report, or NULL if report
  * is invalid.
  **/
-gchar* gnc_report_name( SCM report );
+gchar* gnc_report_name(SCM report);
 
 /* returns #f if the report id cannot be found */
 SCM gnc_report_find(gint id);
+
 void gnc_report_remove_by_id(gint id);
+
 gint gnc_report_add(SCM report);
 
 void gnc_reports_flush_global(void);
-GHashTable *gnc_reports_get_global(void);
+
+GHashTable* gnc_reports_get_global(void);
 
 gchar* gnc_get_default_report_font_family(void);
 
-gboolean gnc_saved_reports_backup (void);
-gboolean gnc_saved_reports_write_to_file (const gchar* report_def, gboolean overwrite);
+gboolean gnc_saved_reports_backup(void);
 
+gboolean gnc_saved_reports_write_to_file(const gchar* report_def, gboolean overwrite);
+
+#ifdef __cplusplus
+} //extern "C"
+/**
+ * Obtain a GncOptionDB* from Scheme
+ *
+ * When report or stylesheet options are generated in Scheme the GncObjectDB is
+ * wrapped in a std::unique_ptr and then in a Guile SMOB by SWIG. The GUI code
+ * needs a reference to the GncObjectDB and we don't want to introduce swig
+ * library dependencies.
+ *
+ * @param dispatch The scheme dispatch function returned by gnc:new-options
+ * @return GncOptiondDB* Do not free this pointer!
+ */
+GncOptionDB* gnc_get_optiondb_from_dispatcher(SCM dispatcher);
+#endif
 #endif
