@@ -36,6 +36,8 @@
 (use-modules (srfi srfi-1))
 (use-modules (ice-9 match))
 
+(define trep-uuid "2fe3b9833af044abb929a88d5a59620f")
+
 (define reportname (N_ "Budget Report"))
 
 ;; define all option's names so that they are properly defined
@@ -52,6 +54,8 @@
 (define opthelp-show-notes (N_ "Display a column for the budget notes."))
 (define optname-show-actual (N_ "Show Actual"))
 (define opthelp-show-actual (N_ "Display a column for the actual values."))
+(define optname-show-trep (N_ "Link to actual transactions"))
+(define opthelp-show-trep (N_ "Show the actual transactions for the budget period"))
 (define optname-show-difference (N_ "Show Difference"))
 (define opthelp-show-difference (N_ "Display the difference as budget - actual."))
 (define optname-accumulate (N_ "Use accumulated amounts"))
@@ -94,19 +98,15 @@
 
 ;;List of common helper functions, that is not bound only to options generation or report evaluation
 (define (get-option-val options pagename optname)
-  (gnc:option-value
-   (gnc:lookup-option options pagename optname)))
+  (gnc-optiondb-lookup-value options pagename optname))
 
 (define (set-option-enabled options page opt-name enabled)
-  (gnc-option-db-set-option-selectable-by-name
+  (gnc-optiondb-set-option-selectable-by-name
    options page opt-name enabled))
 
 ;; options generator
 (define (budget-report-options-generator)
-  (let* ((options (gnc:new-options))
-         (add-option
-          (lambda (new-option)
-            (gnc:register-option options new-option)))
+  (let* ((options (gnc-new-optiondb))
          (period-options
           (list (vector 'first (N_ "First budget period"))
                 (vector 'previous (N_ "Previous budget period"))
@@ -118,21 +118,18 @@
          (ui-start-period-type 'current)
          (ui-end-period-type 'next))
 
-    (gnc:register-option
-     options
-     (gnc:make-budget-option
+    (gnc-register-budget-option options
       gnc:pagename-general optname-budget
-      "a" (N_ "Budget to use.")))
+      "a" (N_ "Budget to use.")
+      (gnc-budget-get-default (gnc-get-current-book)))
 
-    (add-option
-     (gnc:make-simple-boolean-option
+    (gnc-register-simple-boolean-option options
       gnc:pagename-general optname-accumulate
-      "b" opthelp-accumulate #f))
+      "b" opthelp-accumulate #f)
 
-    (add-option
-     (gnc:make-complex-boolean-option
+    (gnc-register-complex-boolean-option options
       gnc:pagename-general optname-use-budget-period-range
-      "f" opthelp-use-budget-period-range #f #f
+      "f" opthelp-use-budget-period-range #f
       (lambda (value)
         (for-each
          (lambda (opt)
@@ -148,56 +145,50 @@
                             optname-budget-period-end-exact
                             (and value (eq? 'manual ui-end-period-type)))
 
-        (set! ui-use-periods value))))
+        (set! ui-use-periods value)))
 
-    (add-option
-     (gnc:make-multichoice-callback-option
+    (gnc-register-multichoice-callback-option options
       gnc:pagename-general optname-budget-period-start
-      "g1.1" opthelp-budget-period-start 'current period-options #f
+      "g1.1" opthelp-budget-period-start "current" period-options
       (lambda (new-val)
         (set-option-enabled options gnc:pagename-general
                             optname-budget-period-start-exact
                             (and ui-use-periods (eq? 'manual new-val)))
-        (set! ui-start-period-type new-val))))
+        (set! ui-start-period-type new-val)))
 
-    (add-option
-     (gnc:make-number-range-option
+    (gnc-register-number-range-option options
       gnc:pagename-general optname-budget-period-start-exact
       "g1.2" opthelp-budget-period-start-exact
       ;; FIXME: It would be nice if the max number of budget periods (60) was
       ;; defined globally somewhere so we could reference it here.  However, it
       ;; only appears to be defined currently in src/gnome/glade/budget.glade.
-      1 1 60 0 1))
+      1 1 60 1)
 
-    (add-option
-     (gnc:make-multichoice-callback-option
+    (gnc-register-multichoice-callback-option options
       gnc:pagename-general optname-budget-period-end
-      "g2.1" opthelp-budget-period-end 'next period-options #f
+      "g2.1" opthelp-budget-period-end "next" period-options
       (lambda (new-val)
         (set-option-enabled options gnc:pagename-general
                             optname-budget-period-end-exact
                             (and ui-use-periods (eq? 'manual new-val)))
-        (set! ui-end-period-type new-val))))
+        (set! ui-end-period-type new-val)))
 
-    (add-option
-     (gnc:make-number-range-option
+    (gnc-register-number-range-option options
       gnc:pagename-general optname-budget-period-end-exact
       "g2.2" opthelp-budget-period-end-exact
       ;; FIXME: It would be nice if the max number of budget periods (60) was
       ;; defined globally somewhere so we could reference it here.  However, it
       ;; only appears to be defined currently in src/gnome/glade/budget.glade.
-      1 1 60 0 1))
+      1 1 60 1)
     ;; accounts to work on
 
-    (add-option
-     (gnc:make-simple-boolean-option
+    (gnc-register-simple-boolean-option options
       gnc:pagename-general optname-period-collapse-before
-      "g3" opthelp-period-collapse-before #t))
+      "g3" opthelp-period-collapse-before #t)
 
-    (add-option
-     (gnc:make-simple-boolean-option
+    (gnc-register-simple-boolean-option options
       gnc:pagename-general optname-period-collapse-after
-      "g4" opthelp-period-collapse-after #t))
+      "g4" opthelp-period-collapse-after #t)
 
     (gnc:options-add-account-selection!
      options gnc:pagename-accounts optname-display-depth
@@ -209,38 +200,37 @@
         (gnc-account-get-descendants-sorted (gnc-get-current-root-account))))
      #f)
 
-    (add-option
-     (gnc:make-simple-boolean-option
+    (gnc-register-simple-boolean-option options
       gnc:pagename-accounts optname-bottom-behavior
-      "c" opthelp-bottom-behavior #f))
+      "c" opthelp-bottom-behavior #f)
 
     ;; columns to display
-    (add-option
-     (gnc:make-complex-boolean-option
+    (gnc-register-complex-boolean-option options
       gnc:pagename-display optname-show-budget
-      "s1" opthelp-show-budget #t #f
+      "s1" opthelp-show-budget #t
       (lambda (x)
-        (set-option-enabled options gnc:pagename-display optname-show-notes x))))
-    (add-option
-     (gnc:make-simple-boolean-option
+        (set-option-enabled options gnc:pagename-display optname-show-notes x)))
+    (gnc-register-simple-boolean-option options
       gnc:pagename-display optname-show-notes
-      "s15" opthelp-show-notes #t))
-    (add-option
-     (gnc:make-simple-boolean-option
+      "s15" opthelp-show-notes #t)
+    (gnc-register-complex-boolean-option options
       gnc:pagename-display optname-show-actual
-      "s2" opthelp-show-actual #t))
-    (add-option
-     (gnc:make-simple-boolean-option
+      "s2" opthelp-show-actual #t
+      (lambda (x)
+        (gnc-optiondb-set-option-selectable-by-name
+         options gnc:pagename-display optname-show-trep x)))
+    (gnc-register-simple-boolean-option options
+      gnc:pagename-display optname-show-trep
+      "s25" opthelp-show-trep #f)
+    (gnc-register-simple-boolean-option options
       gnc:pagename-display optname-show-difference
-      "s3" opthelp-show-difference #f))
-    (add-option
-     (gnc:make-simple-boolean-option
+      "s3" opthelp-show-difference #f)
+    (gnc-register-simple-boolean-option options
       gnc:pagename-display optname-show-totalcol
-      "s4" opthelp-show-totalcol #f))
-    (add-option
-     (gnc:make-simple-boolean-option
+      "s4" opthelp-show-totalcol #f)
+    (gnc-register-simple-boolean-option options
       gnc:pagename-display optname-show-zb-accounts
-      "s5" opthelp-show-zb-accounts #t))
+      "s5" opthelp-show-zb-accounts #t)
 
     ;; Set the general page as default option tab
     (gnc:options-set-default-section options gnc:pagename-general)
@@ -276,11 +266,12 @@
 ;;   budget - budget to use
 ;;   params - report parameters
 (define (gnc:html-table-add-budget-values!
-         html-table acct-table budget params)
+         html-table acct-table budget params report-obj)
   (let* ((get-val (lambda (alist key)
                     (let ((lst (assoc-ref alist key)))
                       (and lst (car lst)))))
          (show-actual? (get-val params 'show-actual))
+         (show-trep? (get-val params 'show-trep))
          (show-budget? (get-val params 'show-budget))
          (show-diff? (get-val params 'show-difference))
          (show-note? (get-val params 'show-note))
@@ -348,8 +339,6 @@
       (let* ((comm (xaccAccountGetCommodity acct))
              (reverse-balance? (gnc-reverse-balance acct))
              (maybe-negate (lambda (amt) (if reverse-balance? (- amt) amt)))
-             (unreversed? (gnc-using-unreversed-budgets
-                           (gnc-get-current-book))) ;fwd-compatibility
              (allperiods (filter number? (gnc:list-flatten column-list)))
              (total-periods (if (and accumulate? (not (null? allperiods)))
                                 (iota (1+ (apply max allperiods)))
@@ -368,7 +357,7 @@
         ;;
         ;; Returns
         ;;   col - next column
-        (define (disp-cols style-tag col0
+        (define (disp-cols style-tag col0 acct start-date end-date
                            bgt-val act-val dif-val note)
           (let* ((col1 (+ col0 (if show-budget? 1 0)))
                  (col2 (+ col1 (if show-actual? 1 0)))
@@ -383,7 +372,19 @@
                 (gnc:html-table-set-cell/tag!
                  html-table rownum col1
                  style-tag
-                 (gnc:make-gnc-monetary comm act-val)))
+                 (if show-trep?
+                     (gnc:make-html-text
+                      (gnc:html-markup-anchor
+                       (gnc:make-report-anchor
+                        trep-uuid report-obj
+                        (list
+                         (list "General" "Start Date" (cons 'absolute start-date))
+                         (list "General" "End Date" (cons 'absolute end-date))
+                         (list "Accounts" "Accounts" (gnc-accounts-and-all-descendants (list acct)))
+                         (list "Currency" "Common Currency" #t)
+                         (list "Currency" "Report's currency" (gnc-account-get-currency-or-parent acct))))
+                       (gnc:make-gnc-monetary comm act-val)))
+                     (gnc:make-gnc-monetary comm act-val))))
             (if show-diff?
                 (gnc:html-table-set-cell/tag!
                  html-table rownum col2
@@ -399,8 +400,7 @@
            ((null? column-list)
             #f)
 
-           ;; fwd-compatibility for unreversed budgets
-           ((and (eq? (car column-list) 'total) unreversed?)
+           ((eq? (car column-list) 'total)
             (let* ((bgt-total (maybe-negate
                                (gnc:get-account-periodlist-budget-value
                                 budget acct total-periods)))
@@ -409,24 +409,12 @@
                                 budget acct total-periods)))
                    (dif-total (- bgt-total act-total)))
               (loop (cdr column-list)
-                    (disp-cols "total-number-cell" current-col
+                    (disp-cols "total-number-cell" current-col acct
+                               (gnc-budget-get-period-start-date budget (car total-periods))
+                               (gnc-budget-get-period-end-date budget (last total-periods))
                                bgt-total act-total dif-total #f))))
 
-           ((eq? (car column-list) 'total)
-            (let* ((bgt-total (gnc:get-account-periodlist-budget-value
-                               budget acct total-periods))
-                   (act-total (gnc:get-account-periodlist-actual-value
-                               budget acct total-periods))
-                   (act-total (if reverse-balance? (- act-total) act-total))
-                   (dif-total (if income-acct?
-                                  (- act-total bgt-total)
-                                  (- bgt-total act-total))))
-              (loop (cdr column-list)
-                    (disp-cols "total-number-cell" current-col
-                               bgt-total act-total dif-total #f))))
-
-           ;; fwd-compatibility for unreversed budgets
-           (unreversed?
+           (else
             (let* ((period-list (cond
                                  ((list? (car column-list)) (car column-list))
                                  (accumulate? (iota (1+ (car column-list))))
@@ -442,29 +430,9 @@
                               budget acct period-list)))
                    (dif-val (- bgt-val act-val)))
               (loop (cdr column-list)
-                    (disp-cols "number-cell" current-col
-                               bgt-val act-val dif-val note))))
-
-           (else
-            (let* ((period-list (cond
-                                 ((list? (car column-list)) (car column-list))
-                                 (accumulate? (iota (1+ (car column-list))))
-                                 (else (list (car column-list)))))
-                   (note (and (= 1 (length period-list))
-                              (gnc-budget-get-account-period-note
-                               budget acct (car period-list))))
-                   (bgt-val (gnc:get-account-periodlist-budget-value
-                             budget acct period-list))
-                   (act-abs (gnc:get-account-periodlist-actual-value
-                             budget acct period-list))
-                   (act-val (if reverse-balance?
-                                (- act-abs)
-                                act-abs))
-                   (dif-val (if income-acct?
-                                (- act-val bgt-val)
-                                (- bgt-val act-val))))
-              (loop (cdr column-list)
-                    (disp-cols "number-cell" current-col
+                    (disp-cols "number-cell" current-col acct
+                               (gnc-budget-get-period-start-date budget (car period-list))
+                               (gnc-budget-get-period-end-date budget (car period-list))
                                bgt-val act-val dif-val note))))))))
 
     ;; Adds header rows to the budget report.  The columns are
@@ -727,6 +695,8 @@
               (list
                (list 'show-actual
                      (get-option gnc:pagename-display optname-show-actual))
+               (list 'show-trep
+                     (get-option gnc:pagename-display optname-show-trep))
                (list 'show-budget
                      (get-option gnc:pagename-display optname-show-budget))
                (list 'show-difference
@@ -771,7 +741,8 @@
         (let ((html-table (gnc:html-table-add-account-balances #f acct-table '())))
 
           ;; ... then the budget values
-          (gnc:html-table-add-budget-values! html-table acct-table budget paramsBudget)
+          (gnc:html-table-add-budget-values! html-table acct-table budget
+                                             paramsBudget report-obj)
 
           ;; hmmm... I expected that add-budget-values would have to
           ;; clear out any unused columns to the right, out to the
