@@ -23,7 +23,7 @@
   (test-end "test-average-balance"))
 
 (define (set-option! options page tag value)
-  ((gnc:option-setter (gnc:lookup-option options page tag)) value))
+  (gnc-set-option options page tag value))
 
 (define (teardown)
   (gnc-clear-current-session))
