@@ -24,10 +24,8 @@
 #ifndef __GNC_SQL_OBJECT_BACKEND_HPP__
 #define __GNC_SQL_OBJECT_BACKEND_HPP__
 
-extern "C"
-{
 #include <qof.h>
-}
+
 #include <memory>
 #include <string>
 #include <vector>
