@@ -24,14 +24,11 @@
 \********************************************************************/
 #include <glib.h>
 
-extern "C"
-{
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
 #include <AccountP.h>
 #include <Account.h>
-}
 
 #include "gnc-xml-helper.h"
 #include "sixtp.h"
@@ -124,13 +121,13 @@ gnc_account_dom_tree_create (Account* act,
     }
 
     str = xaccAccountGetCode (act);
-    if (str && strlen (str) > 0)
+    if (str && *str)
     {
         xmlAddChild (ret, text_to_dom_tree (act_code_string, str));
     }
 
     str = xaccAccountGetDescription (act);
-    if (str && strlen (str) > 0)
+    if (str && *str)
     {
         xmlAddChild (ret, text_to_dom_tree (act_description_string, str));
     }
