@@ -23,8 +23,6 @@
 
 #define __EXTENSIONS__
 #include <guid.hpp>
-extern "C"
-{
 #include <config.h>
 
 #include <ctype.h>
@@ -40,7 +38,6 @@ extern "C"
 #include "strptime.h"
 #endif
 #include <gnc-date.h>
-}
 
 #include "sixtp.h"
 #include "sixtp-utils.h"
@@ -174,7 +171,7 @@ string_to_gint64 (const gchar* str, gint64* v)
     g_return_val_if_fail (str, FALSE);
 
     /* must use "<" here because %n's effects aren't well defined */
-    if (sscanf (str, " " QOF_SCANF_LLD "%n", &v_in, &num_read) < 1)
+    if (sscanf (str, " %lld%n", &v_in, &num_read) < 1)
     {
         return (FALSE);
     }
@@ -614,7 +611,8 @@ generic_gnc_numeric_end_handler (gpointer data_for_children,
         num = g_new (gnc_numeric, 1);
         if (num)
         {
-            if (string_to_gnc_numeric (txt, num))
+            *num = gnc_numeric_from_string (txt);
+            if (!gnc_numeric_check (*num))
             {
                 ok = TRUE;
                 *result = num;
