@@ -23,10 +23,7 @@
 
 #ifndef SIXTP_UTILS_H
 #define SIXTP_UTILS_H
-extern "C"
-{
 #include "qof.h"
-}
 #include "sixtp.h"
 
 typedef struct
