@@ -43,6 +43,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdint.h>
+#include <stdbool.h>
 
 #include "Account.h"
 #include "AccountP.h"
@@ -88,47 +89,47 @@ gnc_get_ongoing_scrub (void)
 
 /* ================================================================ */
 
-void
-xaccAccountTreeScrubOrphans (Account *acc, QofPercentageFunc percentagefunc)
+static void add_transactions (const Account *account, GHashTable **ht)
 {
-    if (!acc) return;
-
-    if (abort_now)
-        (percentagefunc)(NULL, -1.0);
-
-    scrub_depth ++;
-    xaccAccountScrubOrphans (acc, percentagefunc);
-    gnc_account_foreach_descendant(acc,
-                                   (AccountCb)xaccAccountScrubOrphans, percentagefunc);
-    scrub_depth--;
+    for (GList *m = xaccAccountGetSplitList (account); m; m = g_list_next (m))
+        g_hash_table_add (*ht, xaccSplitGetParent (m->data));
 }
 
+static GList*
+get_all_transactions (Account *account, bool descendants)
+{
+    GHashTable *ht = g_hash_table_new (g_direct_hash, g_direct_equal);
+    add_transactions (account, &ht);
+    if (descendants)
+        gnc_account_foreach_descendant (account, (AccountCb)add_transactions, &ht);
+    GList *rv = g_hash_table_get_keys (ht);
+    g_hash_table_destroy (ht);
+    return rv;
+}
+
+/* ================================================================ */
+
 static void
 TransScrubOrphansFast (Transaction *trans, Account *root)
 {
-    GList *node;
-    gchar *accname;
+    g_return_if_fail (trans && trans->common_currency && root);
 
-    if (!trans) return;
-    g_return_if_fail (root);
-    g_return_if_fail (trans->common_currency);
-
-    for (node = trans->splits; node; node = node->next)
+    for (GList *node = trans->splits; node; node = node->next)
     {
         Split *split = node->data;
-        Account *orph;
         if (abort_now) break;
 
         if (split->acc) continue;
 
         DEBUG ("Found an orphan\n");
 
-        accname = g_strconcat (_("Orphan"), "-",
-                               gnc_commodity_get_mnemonic (trans->common_currency),
-                               NULL);
-        orph = xaccScrubUtilityGetOrMakeAccount (root, trans->common_currency,
-                                                 accname, ACCT_TYPE_BANK,
-                                                 FALSE, TRUE);
+        gchar *accname = g_strconcat
+            (_("Orphan"), "-", gnc_commodity_get_mnemonic (trans->common_currency),
+             NULL);
+
+        Account *orph = xaccScrubUtilityGetOrMakeAccount
+            (root, trans->common_currency, accname, ACCT_TYPE_BANK, false, true);
+
         g_free (accname);
         if (!orph) continue;
 
@@ -136,43 +137,47 @@ TransScrubOrphansFast (Transaction *trans, Account *root)
     }
 }
 
-void
-xaccAccountScrubOrphans (Account *acc, QofPercentageFunc percentagefunc)
+static void
+AccountScrubOrphans (Account *acc, bool descendants, QofPercentageFunc percentagefunc)
 {
-    GList *node, *splits;
-    const char *str;
-    const char *message = _( "Looking for orphans in account %s: %u of %u");
-    guint total_splits = 0;
-    guint current_split = 0;
-
     if (!acc) return;
     scrub_depth++;
 
-    str = xaccAccountGetName (acc);
-    str = str ? str : "(null)";
-    PINFO ("Looking for orphans in account %s\n", str);
-    splits = xaccAccountGetSplitList(acc);
-    total_splits = g_list_length (splits);
+    GList *transactions = get_all_transactions (acc, descendants);
+    gint total_trans = g_list_length (transactions);
+    const char *message = _( "Looking for orphans in transaction: %u of %u");
+    guint current_trans = 0;
 
-    for (node = splits; node; node = node->next)
+    for (GList *node = transactions; node; current_trans++, node = node->next)
     {
-        Split *split = node->data;
-        if (current_split % 10 == 0)
+        Transaction *trans = node->data;
+        if (current_trans % 10 == 0)
         {
-            char *progress_msg = g_strdup_printf (message, str, current_split, total_splits);
-            (percentagefunc)(progress_msg, (100 * current_split) / total_splits);
+            char *progress_msg = g_strdup_printf (message, current_trans, total_trans);
+            (percentagefunc)(progress_msg, (100 * current_trans) / total_trans);
             g_free (progress_msg);
             if (abort_now) break;
         }
 
-        TransScrubOrphansFast (xaccSplitGetParent (split),
-                               gnc_account_get_root (acc));
-        current_split++;
+        TransScrubOrphansFast (trans, gnc_account_get_root (acc));
     }
     (percentagefunc)(NULL, -1.0);
     scrub_depth--;
+
+    g_list_free (transactions);
 }
 
+void
+xaccAccountScrubOrphans (Account *acc, QofPercentageFunc percentagefunc)
+{
+    AccountScrubOrphans (acc, false, percentagefunc);
+}
+
+void
+xaccAccountTreeScrubOrphans (Account *acc, QofPercentageFunc percentagefunc)
+{
+    AccountScrubOrphans (acc, true, percentagefunc);
+}
 
 void
 xaccTransScrubOrphans (Transaction *trans)
@@ -231,8 +236,10 @@ xaccAccountScrubSplits (Account *account)
     scrub_depth--;
 }
 
-void
-xaccSplitScrub (Split *split)
+/* if dry_run is true, this function will analyze the split and
+   return true if the split will be modified during the actual scrub. */
+static bool
+split_scrub_or_dry_run (Split *split, bool dry_run)
 {
     Account *account;
     Transaction *trans;
@@ -240,14 +247,14 @@ xaccSplitScrub (Split *split)
     gnc_commodity *currency, *acc_commodity;
     int scu;
 
-    if (!split) return;
+    if (!split) return false;
     ENTER ("(split=%p)", split);
 
     trans = xaccSplitGetParent (split);
     if (!trans)
     {
         LEAVE("no trans");
-        return;
+        return false;
     }
 
     account = xaccSplitGetAccount (split);
@@ -257,7 +264,10 @@ xaccSplitScrub (Split *split)
      */
     if (!account)
     {
-        xaccTransScrubOrphans (trans);
+        if (dry_run)
+            return true;
+        else
+            xaccTransScrubOrphans (trans);
         account = xaccSplitGetAccount (split);
     }
 
@@ -269,7 +279,7 @@ xaccSplitScrub (Split *split)
     {
         PINFO ("Free Floating Transaction!");
         LEAVE ("no account");
-        return;
+        return false;
     }
 
     /* Split amounts and values should be valid numbers */
@@ -277,14 +287,20 @@ xaccSplitScrub (Split *split)
     if (gnc_numeric_check (value))
     {
         value = gnc_numeric_zero();
-        xaccSplitSetValue (split, value);
+        if (dry_run)
+            return true;
+        else
+            xaccSplitSetValue (split, value);
     }
 
     amount = xaccSplitGetAmount (split);
     if (gnc_numeric_check (amount))
     {
         amount = gnc_numeric_zero();
-        xaccSplitSetAmount (split, amount);
+        if (dry_run)
+            return true;
+        else
+            xaccSplitSetAmount (split, amount);
     }
 
     currency = xaccTransGetCurrency (trans);
@@ -295,12 +311,15 @@ xaccSplitScrub (Split *split)
     acc_commodity = xaccAccountGetCommodity(account);
     if (!acc_commodity)
     {
-        xaccAccountScrubCommodity (account);
+        if (dry_run)
+            return true;
+        else
+            xaccAccountScrubCommodity (account);
     }
     if (!acc_commodity || !gnc_commodity_equiv(acc_commodity, currency))
     {
         LEAVE ("(split=%p) inequiv currency", split);
-        return;
+        return false;
     }
 
     scu = MIN (xaccAccountGetCommoditySCU (account),
@@ -309,9 +328,12 @@ xaccSplitScrub (Split *split)
     if (gnc_numeric_same (amount, value, scu, GNC_HOW_RND_ROUND_HALF_UP))
     {
         LEAVE("(split=%p) different values", split);
-        return;
+        return false;
     }
 
+    if (dry_run)
+        return true;
+
     /*
      * This will be hit every time you answer yes to the dialog "The
      * current transaction has changed. Would you like to record it.
@@ -327,82 +349,102 @@ xaccSplitScrub (Split *split)
     xaccSplitSetAmount (split, value);
     xaccTransCommitEdit (trans);
     LEAVE ("(split=%p)", split);
+    return true;
+}
+
+/* ================================================================ */
+
+
+static void
+AccountScrubImbalance (Account *acc, bool descendants,
+                       QofPercentageFunc percentagefunc)
+{
+    const char *message = _( "Looking for imbalances in transaction date %s: %u of %u");
+
+    if (!acc) return;
+
+    QofBook *book = qof_session_get_book (gnc_get_current_session ());
+    Account *root = gnc_book_get_root_account (book);
+    GList *transactions = get_all_transactions (acc, descendants);
+    guint count = g_list_length (transactions), curr_trans = 0;
+
+    scrub_depth++;
+    for (GList *node = transactions; node; node = node->next, curr_trans++)
+    {
+        Transaction *trans = node->data;
+        if (abort_now) break;
+
+        PINFO("Start processing transaction %d of %d", curr_trans + 1, count);
+
+        if (curr_trans % 10 == 0)
+        {
+            char *date = qof_print_date (xaccTransGetDate (trans));
+            char *progress_msg = g_strdup_printf (message, date, curr_trans, count);
+            (percentagefunc)(progress_msg, (100 * curr_trans) / count);
+            g_free (progress_msg);
+            g_free (date);
+        }
+
+        TransScrubOrphansFast (trans, root);
+        xaccTransScrubCurrency(trans);
+        xaccTransScrubImbalance (trans, root, NULL);
+
+        PINFO("Finished processing transaction %d of %d", curr_trans + 1, count);
+    }
+    (percentagefunc)(NULL, -1.0);
+    scrub_depth--;
+
+    g_list_free (transactions);
+}
+
+void
+xaccTransScrubSplits (Transaction *trans)
+{
+    if (!trans) return;
+
+    gnc_commodity *currency = xaccTransGetCurrency (trans);
+    if (!currency)
+        PERR ("Transaction doesn't have a currency!");
+
+    bool must_scrub = false;
+
+    for (GList *n = xaccTransGetSplitList (trans); !must_scrub && n; n = g_list_next (n))
+        if (split_scrub_or_dry_run (n->data, true))
+            must_scrub = true;
+
+    if (!must_scrub)
+        return;
+
+    xaccTransBeginEdit(trans);
+    /* The split scrub expects the transaction to have a currency! */
+
+    for (GList *n = xaccTransGetSplitList (trans); n; n = g_list_next (n))
+        xaccSplitScrub (n->data);
+
+    xaccTransCommitEdit(trans);
 }
 
 /* ================================================================ */
 
+void
+xaccSplitScrub (Split *split)
+{
+    split_scrub_or_dry_run (split, false);
+}
+
+/* ================================================================ */
+
+
 void
 xaccAccountTreeScrubImbalance (Account *acc, QofPercentageFunc percentagefunc)
 {
-    if (!acc) return;
-
-    if (abort_now)
-        (percentagefunc)(NULL, -1.0);
-
-    scrub_depth++;
-    xaccAccountScrubImbalance (acc, percentagefunc);
-    gnc_account_foreach_descendant(acc,
-                                   (AccountCb)xaccAccountScrubImbalance, percentagefunc);
-    scrub_depth--;
+    AccountScrubImbalance (acc, true, percentagefunc);
 }
 
 void
 xaccAccountScrubImbalance (Account *acc, QofPercentageFunc percentagefunc)
 {
-    GList *node, *splits;
-    const char *str;
-    const char *message = _( "Looking for imbalances in account %s: %u of %u");
-    gint split_count = 0, curr_split_no = 0;
-
-    if (!acc) return;
-    /* If it's a trading account and an imbalanced transaction is
-     * found the trading splits will be replaced, invalidating the
-     * split list in mid-traversal, see
-     * https://bugs.gnucash.org/show_bug.cgi?id=798346. Also the
-     * transactions will get scrubbed at least twice from their "real"
-     * accounts anyway so doing so from the trading accounts is wasted
-     * effort.
-     */
-    if (xaccAccountGetType(acc) == ACCT_TYPE_TRADING)
-         return;
-
-    scrub_depth++;
-
-    str = xaccAccountGetName(acc);
-    str = str ? str : "(null)";
-    PINFO ("Looking for imbalances in account %s\n", str);
-
-    splits = xaccAccountGetSplitList(acc);
-    split_count = g_list_length (splits);
-    for (node = splits; node; node = node->next)
-    {
-        Split *split = node->data;
-        Transaction *trans = xaccSplitGetParent(split);
-        if (abort_now) break;
-
-        PINFO("Start processing split %d of %d",
-              curr_split_no + 1, split_count);
-
-        if (curr_split_no % 10 == 0)
-        {
-            char *progress_msg = g_strdup_printf (message, str, curr_split_no, split_count);
-            (percentagefunc)(progress_msg, (100 * curr_split_no) / split_count);
-            g_free (progress_msg);
-        }
-
-        TransScrubOrphansFast (xaccSplitGetParent (split),
-                               gnc_account_get_root (acc));
-
-        xaccTransScrubCurrency(trans);
-
-        xaccTransScrubImbalance (trans, gnc_account_get_root (acc), NULL);
-
-        PINFO("Finished processing split %d of %d",
-              curr_split_no + 1, split_count);
-        curr_split_no++;
-    }
-    (percentagefunc)(NULL, -1.0);
-    scrub_depth--;
+    AccountScrubImbalance (acc, false, percentagefunc);
 }
 
 static Split *
@@ -490,7 +532,6 @@ get_trading_split (Transaction *trans, Account *base,
     Account *ns_account;
     Account *account;
     Account* root = gnc_book_get_root_account (xaccTransGetBook (trans));
-    gnc_commodity *root_currency = find_root_currency ();
 
     trading_account = xaccScrubUtilityGetOrMakeAccount (root,
                                                         NULL,
