@@ -66,8 +66,6 @@ struct _gncInvoice
     time64        date_opened;
     time64        date_posted;
 
-    char          *doclink;
-
     gnc_numeric   to_charge_amount;
 
     gnc_commodity *currency;
@@ -132,7 +130,7 @@ enum
 };
 
 /* GObject Initialization */
-G_DEFINE_TYPE(GncInvoice, gnc_invoice, QOF_TYPE_INSTANCE);
+G_DEFINE_TYPE(GncInvoice, gnc_invoice, QOF_TYPE_INSTANCE)
 
 static void
 gnc_invoice_init (GncInvoice* inv)
@@ -285,9 +283,6 @@ impl_get_typed_referring_object_list (const QofInstance* inst, const QofInstance
     return qof_instance_get_referring_object_list_from_collection (qof_instance_get_collection (inst), ref);
 }
 
-static const char*
-is_unset = "unset";
-
 static void
 gnc_invoice_class_init (GncInvoiceClass *klass)
 {
@@ -333,7 +328,6 @@ GncInvoice *gncInvoiceCreate (QofBook *book)
     invoice->active = TRUE;
 
     invoice->to_charge_amount = gnc_numeric_zero ();
-    invoice->doclink = (char*) is_unset;
 
     qof_event_gen (&invoice->inst, QOF_EVENT_CREATE, NULL);
 
@@ -379,10 +373,7 @@ GncInvoice *gncInvoiceCopy (const GncInvoice *from)
     // Oops. Do not forget to copy the pointer to the correct currency here.
     invoice->currency = from->currency;
 
-    if (from->doclink == is_unset)
-        invoice->doclink = (char*)is_unset;
-    else
-        gncInvoiceSetDocLink (invoice, from->doclink);
+    gncInvoiceSetDocLink (invoice, gncInvoiceGetDocLink (from));
 
     // Copy all invoice->entries
     for (node = from->entries; node; node = node->next)
@@ -435,13 +426,14 @@ static void gncInvoiceFree (GncInvoice *invoice)
     g_list_free (invoice->entries);
     g_list_free (invoice->prices);
 
-    if (invoice->printname) g_free (invoice->printname);
+    if (invoice->printname)
+        g_free (invoice->printname);
 
-    if (invoice->terms)
-        gncBillTermDecRef (invoice->terms);
-
-    if (invoice->doclink != is_unset)
-        g_free (invoice->doclink);
+    if (!qof_book_shutting_down (qof_instance_get_book (QOF_INSTANCE(invoice))))
+    {
+        if (invoice->terms)
+            gncBillTermDecRef (invoice->terms);
+    }
 
     /* qof_instance_release (&invoice->inst); */
     g_object_unref (invoice);
@@ -554,28 +546,18 @@ void gncInvoiceSetDocLink (GncInvoice *invoice, const char *doclink)
 {
     if (!invoice || !doclink) return;
 
-    if (invoice->doclink != is_unset)
-    {
-        if (!g_strcmp0 (doclink, invoice->doclink))
-            return;
-
-        g_free (invoice->doclink);
-    }
-
     gncInvoiceBeginEdit (invoice);
 
     if (doclink[0] == '\0')
     {
-        invoice->doclink = NULL;
         qof_instance_set_kvp (QOF_INSTANCE (invoice), NULL, 1, GNC_INVOICE_DOCLINK);
     }
     else
     {
         GValue v = G_VALUE_INIT;
         g_value_init (&v, G_TYPE_STRING);
-        g_value_set_string (&v, doclink);
+        g_value_set_static_string (&v, doclink);
         qof_instance_set_kvp (QOF_INSTANCE (invoice), &v, 1, GNC_INVOICE_DOCLINK);
-        invoice->doclink = g_strdup (doclink);
         g_value_unset (&v);
     }
     qof_instance_set_dirty (QOF_INSTANCE(invoice));
@@ -778,12 +760,13 @@ void gncInvoiceSortEntries (GncInvoice *invoice)
 
 void gncInvoiceRemoveEntries (GncInvoice *invoice)
 {
-    GList *node;
-
     if (!invoice) return;
 
-    for (node = invoice->entries; node; node = node->next)
+    // gnc{Bill,Invoice}RemoveEntry free the "entry" node.
+    // Make sure to save "next" first.
+    for (GList *next, *node = invoice->entries; node; node = next)
     {
+        next = node->next;
         GncEntry *entry = node->data;
 
         switch (gncInvoiceGetOwnerType (invoice))
@@ -894,15 +877,13 @@ const char * gncInvoiceGetNotes (const GncInvoice *invoice)
 const char * gncInvoiceGetDocLink (const GncInvoice *invoice)
 {
     if (!invoice) return NULL;
-    if (invoice->doclink == is_unset)
-    {
-        GValue v = G_VALUE_INIT;
-        GncInvoice *inv = (GncInvoice*) invoice;
-        qof_instance_get_kvp (QOF_INSTANCE(invoice), &v, 1, GNC_INVOICE_DOCLINK);
-        inv->doclink = G_VALUE_HOLDS_STRING(&v) ? g_value_dup_string (&v) : NULL;
-        g_value_unset (&v);
-    }
-    return invoice->doclink;
+
+    GValue v = G_VALUE_INIT;
+    qof_instance_get_kvp (QOF_INSTANCE(invoice), &v, 1, GNC_INVOICE_DOCLINK);
+    const char *rv = G_VALUE_HOLDS_STRING(&v) ? g_value_get_string (&v) : NULL;
+    g_value_unset (&v);
+
+    return rv;
 }
 
 GncOwnerType gncInvoiceGetOwnerType (const GncInvoice *invoice)
@@ -958,7 +939,7 @@ static gnc_numeric gncInvoiceGetNetAndTaxesInternal (GncInvoice *invoice, gboole
     for (node = gncInvoiceGetEntries (invoice); node; node = node->next)
     {
         GncEntry *entry = node->data;
-        gnc_numeric value, tax;
+        gnc_numeric value;
 
         if (use_payment_type && gncEntryGetBillPayment (entry) != type)
             continue;
@@ -1006,7 +987,6 @@ static gnc_numeric gncInvoiceGetTotalInternal (GncInvoice *invoice, gboolean use
 {
     AccountValueList *taxes;
     gnc_numeric total;
-    int denom;
 
     if (!invoice) return gnc_numeric_zero ();
 
@@ -1052,7 +1032,6 @@ gnc_numeric gncInvoiceGetTotalOf (GncInvoice *invoice, GncEntryPaymentType type)
 
 AccountValueList *gncInvoiceGetTotalTaxList (GncInvoice *invoice)
 {
-    gnc_numeric unused;
     AccountValueList *taxes;
     if (!invoice) return NULL;
 
