@@ -148,6 +148,18 @@ TEST(gncnumeric_constructors, test_string_constructor)
     GncNumeric neg_continental_decimal("-123,456");
     EXPECT_EQ(-123456, neg_continental_decimal.num());
     EXPECT_EQ(1000, neg_continental_decimal.denom());
+    GncNumeric from_scientific("1.234e4");
+    EXPECT_EQ(12340, from_scientific.num());
+    EXPECT_EQ(1, from_scientific.denom());
+    GncNumeric from_no_int_scientific(".234e4");
+    EXPECT_EQ(2340, from_no_int_scientific.num());
+    EXPECT_EQ(1, from_no_int_scientific.denom());
+    GncNumeric from_int_only_scientific("1234e2");
+    EXPECT_EQ(123400, from_int_only_scientific.num());
+    EXPECT_EQ(1, from_int_only_scientific.denom());
+    GncNumeric from_neg_sci("1.234e-2");
+    EXPECT_EQ(1234, from_neg_sci.num());
+    EXPECT_EQ(100000, from_neg_sci.denom());
     ASSERT_NO_THROW(GncNumeric hex_rational("0x1e240/0x1c8"));
     GncNumeric hex_rational("0x1e240/0x1c8");
     EXPECT_EQ(123456, hex_rational.num());
@@ -168,6 +180,28 @@ TEST(gncnumeric_constructors, test_string_constructor)
     GncNumeric neg_embedded("The number is -123456/456");
     EXPECT_EQ(-123456, neg_embedded.num());
     EXPECT_EQ(456, neg_embedded.denom());
+    ASSERT_NO_THROW(GncNumeric integer_fraction("The number is 1234 567/890"));
+    GncNumeric integer_fraction("The number is 1234 567/890");
+    EXPECT_EQ(1098827, integer_fraction.num());
+    EXPECT_EQ(890, integer_fraction.denom());
+    ASSERT_NO_THROW(GncNumeric neg_integer_fraction("The number is -1234 567/890"));
+    GncNumeric neg_integer_fraction("The number is -1234 567/890");
+    EXPECT_EQ(-1098827, neg_integer_fraction.num());
+    EXPECT_EQ(890, neg_integer_fraction.denom());
+    GncNumeric integer_large_fraction("The number is 1234 4567/890");
+    EXPECT_EQ(1102827, integer_large_fraction.num());
+    EXPECT_EQ(890, integer_large_fraction.denom());
+    GncNumeric neg_integer_large_fraction("The number is -1234 4567/890");
+    EXPECT_EQ(-1102827, neg_integer_large_fraction.num());
+    EXPECT_EQ(890, neg_integer_large_fraction.denom());
+    ASSERT_NO_THROW(GncNumeric zero_integer_fraction("The number is 0 567/890"));
+    GncNumeric zero_integer_fraction("The number is 0 567/890");
+    EXPECT_EQ(567, zero_integer_fraction.num());
+    EXPECT_EQ(890, zero_integer_fraction.denom());
+    ASSERT_NO_THROW(GncNumeric neg_zero_integer_fraction("The number is -0 567/890"));
+    GncNumeric neg_zero_integer_fraction("The number is -0 567/890");
+    EXPECT_EQ(-567, neg_zero_integer_fraction.num());
+    EXPECT_EQ(890, neg_zero_integer_fraction.denom());
     EXPECT_THROW(GncNumeric throw_zero_denom("123/0"), std::invalid_argument);
     EXPECT_THROW(GncNumeric overflow("12345678987654321.123456"),
                  std::overflow_error);
@@ -185,6 +219,12 @@ TEST(gncnumeric_constructors, test_string_constructor)
     GncNumeric neg_decimal_frac_nozero("-.12345");
     EXPECT_EQ(-12345, neg_decimal_frac_nozero.num());
     EXPECT_EQ(100000, neg_decimal_frac_nozero.denom());
+    GncNumeric big_denom(".123456789012345678");
+    EXPECT_EQ(123456789012345678, big_denom.num());
+    EXPECT_EQ(1000000000000000000, big_denom.denom());
+    GncNumeric too_big_denom(".1234567890123456789");
+    EXPECT_EQ(123456789012345678, too_big_denom.num());
+    EXPECT_EQ(1000000000000000000, too_big_denom.denom());
 }
 
 TEST(gncnumeric_output, string_output)
@@ -548,4 +588,16 @@ TEST(gnc_numeric_functions, test_conversion_to_decimal)
     EXPECT_NO_THROW(r = c.to_decimal());
     EXPECT_EQ(27434842, r.num());
     EXPECT_EQ(100, r.denom());
+    GncNumeric d(11900000000, 85000000);
+    EXPECT_NO_THROW(r = d.to_decimal());
+    EXPECT_EQ(140, r.num());
+    EXPECT_EQ(1, r.denom());
+    GncNumeric e(11050000000, 65000000);
+    EXPECT_NO_THROW(r = e.to_decimal());
+    EXPECT_EQ(170, r.num());
+    EXPECT_EQ(1, r.denom());
+    GncNumeric f(5000000000, 50000000 );
+    EXPECT_NO_THROW(r = f.to_decimal());
+    EXPECT_EQ(100, r.num());
+    EXPECT_EQ(1, r.denom());
 }
