@@ -22,8 +22,6 @@
  */
 #include <glib.h>
 
-extern "C"
-{
 #include <config.h>
 #include "qof.h"
 #include "cashobjects.h"
@@ -32,19 +30,18 @@ extern "C"
 #include "gnc-engine.h"
 #include "test-engine-stuff.h"
 #include "test-stuff.h"
-}
 
 static int
 test_trans_query (Transaction *trans, gpointer data)
 {
     QofBook *book = QOF_BOOK(data);
     GList *list;
-    QofQuery *q;
 
-    q = make_trans_query (trans, ALL_QT);
+    QofQuery *q = make_trans_query (trans, ALL_QT);
     qof_query_set_book (q, book);
-
     list = xaccQueryGetTransactions (q, QUERY_TXN_MATCH_ANY);
+    qof_query_destroy (q);
+
     if (g_list_length (list) != 1)
     {
         failure_args ("test number returned", __FILE__, __LINE__,
@@ -62,7 +59,6 @@ test_trans_query (Transaction *trans, gpointer data)
     }
 
     success ("found right transaction");
-    qof_query_destroy (q);
     g_list_free (list);
 
     return 0;
@@ -83,7 +79,7 @@ run_test (void)
 
     xaccAccountTreeForEachTransaction (root, test_trans_query, book);
 
-    qof_session_end (session);
+    qof_session_destroy (session);
 }
 
 int
